@@ -37,10 +37,23 @@ def round_trip_load_yaml(file_path):
     return payload
 
 
-def load_yaml_configs(path):
+def load_yaml_configs(path, config_path):
     passed: List[str] = []
     failed: List[str] = []
     content: Dict = {}
+
+    def _get_content_by_key(source: Dict, key: str, default_value):
+        result = {}
+        for t in source:
+            result[t] = {}
+            result[t][key] = source[t].get(key, default_value)
+            result[t]['columns'] = {}
+            for c in source[t].get('columns', []):
+                result[t]['columns'][c] = {}
+                result[t]['columns'][c][key] = source[t]['columns'][c].get(key, default_value)
+
+        return result
+
     for root, dirs, files in os.walk(path):
         for file in files:
             if file.endswith('.yml') or file.endswith('.yaml'):
@@ -50,7 +63,17 @@ def load_yaml_configs(path):
                     failed.append(file_path)
                 else:
                     passed.append(file_path)
-                    always_merger.merge(content, payload)
+                    assertions = _get_content_by_key(payload, 'tests', [])
+                    always_merger.merge(content, assertions)
+
+    if not config_path:
+        return passed, failed, content
+
+    project_config = safe_load_yaml(config_path)
+    if project_config:
+        payload = project_config.get('tables', {})
+        descriptions = _get_content_by_key(payload, 'description', '')
+        always_merger.merge(content, descriptions)
 
     return passed, failed, content
 
@@ -200,14 +223,14 @@ class AssertionResult:
         return self
 
     def success(self, actual=None):
-        if actual:
+        if actual is not None:
             self.actual = actual
 
         self._success = True
         return self
 
     def fail(self, actual=None):
-        if actual:
+        if actual is not None:
             self.actual = actual
 
         self._success = False
@@ -295,6 +318,7 @@ class AssertionEngine:
     This class is used to evaluate the assertion.
     """
     PIPERIDER_WORKSPACE_NAME = '.piperider'
+    PIPERIDER_CONFIG_PATH = os.path.join(os.getcwd(), PIPERIDER_WORKSPACE_NAME, 'config.yml')
     PIPERIDER_ASSERTION_SEARCH_PATH = os.path.join(os.getcwd(), PIPERIDER_WORKSPACE_NAME, 'assertions')
     PIPERIDER_ASSERTION_PLUGIN_PATH = os.path.join(os.getcwd(), PIPERIDER_WORKSPACE_NAME, 'plugins')
     PIPERIDER_ASSERTION_SUPPORT_METRICS = ['distribution', 'range', 'missing_value']
@@ -319,7 +343,7 @@ class AssertionEngine:
         """
         return load_yaml_configs(assertion_search_path)
 
-    def load_assertions(self, profiling_result=None):
+    def load_assertions(self, profiling_result=None, config_path=PIPERIDER_CONFIG_PATH):
         """
         This method is used to load assertions from the specific path.
         :param assertion_search_path:
@@ -330,7 +354,7 @@ class AssertionEngine:
         {'nodes': {'tests': [], 'columns': {'uid': {'tests': []}, 'type': {'tests': []}, 'name': {'tests': []}, 'created_at': {'tests': []}, 'updated_at': {'tests': []}, 'metadata': {'tests': []}}}, 'edges': {'tests': [], 'columns': {'n1_uid': {'tests': []}, 'n2_uid': {'tests': []}, 'created_at': {'tests': []}, 'updated_at': {'tests': []}, 'type': {'tests': []}, 'metadata': {'tests': []}}}}
         """
         self.assertions = []
-        self.load_assertion_content()
+        self.load_assertion_content(config_path)
 
         # Load assertio
         if profiling_result:
@@ -380,9 +404,9 @@ class AssertionEngine:
 
         return passed_assertion_files, failed_assertion_files
 
-    def load_assertion_content(self):
+    def load_assertion_content(self, config_path=PIPERIDER_CONFIG_PATH):
         passed_assertion_files, failed_assertion_files, self.assertions_content = load_yaml_configs(
-            self.assertion_search_path)
+            self.assertion_search_path, config_path)
 
         return passed_assertion_files, failed_assertion_files
 
