@@ -1,4 +1,4 @@
-from piperider_cli.assertion_engine.recommended_rules.recommender_assertion import RecommendedAssertion
+from .recommender_assertion import RecommendedAssertion
 
 
 def recommended_table_row_count_assertion(table, column, profiling_result) -> RecommendedAssertion:
@@ -34,20 +34,20 @@ def recommended_column_min_assertion(table, column, profiling_result) -> Recomme
     column_metric = profiling_result['tables'][table]['columns'][column]
     column_type = column_metric['type']
     if column_type == 'numeric':
-        total = column_metric['total']
-        if not total:
+        valids = column_metric['valids']
+        if not valids:
             return None
 
         column_min = column_metric['min']
-        distribution_counts = column_metric['distribution']['counts'] if column_metric['distribution'] else []
+        histogram_counts = column_metric['histogram']['counts'] if column_metric['histogram'] else []
 
         count = 0
-        for i, v in enumerate(reversed(distribution_counts)):
+        for i, v in enumerate(reversed(histogram_counts)):
             count = count + v
-            if i == len(distribution_counts) // 2:
+            if i == len(histogram_counts) // 2:
                 break
 
-        if count / total > 0.95:
+        if count / valids > 0.95:
             test_function_name = 'assert_column_min_in_range'
             assertion_values = {
                 'min': sorted([round(column_min * 0.9, 4), round(column_min * 1.1, 4)])
@@ -65,20 +65,20 @@ def recommended_column_max_assertion(table, column, profiling_result) -> Recomme
     column_metric = profiling_result['tables'][table]['columns'][column]
     column_type = column_metric['type']
     if column_type == 'numeric':
-        total = column_metric['total']
-        if not total:
+        valids = column_metric['valids']
+        if not valids:
             return None
 
         column_max = column_metric['max']
-        distribution_counts = column_metric['distribution']['counts'] if column_metric['distribution'] else []
+        histogram_counts = column_metric['histogram']['counts'] if column_metric['histogram'] else []
 
         count = 0
-        for i, v in enumerate(distribution_counts):
+        for i, v in enumerate(histogram_counts):
             count = count + v
-            if i == len(distribution_counts) // 2:
+            if i == len(histogram_counts) // 2:
                 break
 
-        if count / total > 0.95:
+        if count / valids > 0.95:
             test_function_name = 'assert_column_max_in_range'
             assertion_values = {
                 'max': sorted([round(column_max * 0.9, 4), round(column_max * 1.1, 4)])
@@ -96,10 +96,10 @@ def recommended_column_unique_assertion(table, column, profiling_result) -> Reco
     column_metric = profiling_result['tables'][table]['columns'][column]
     column_type = column_metric['type']
     if column_type == 'string':
-        non_nulls = column_metric['non_nulls']
+        valids = column_metric['valids']
         distinct = column_metric['distinct']
 
-        if non_nulls > 0 and distinct == non_nulls:
+        if valids > 0 and distinct == valids:
             test_function_name = 'assert_column_unique'
             assertion = RecommendedAssertion(test_function_name, None)
             return assertion
@@ -121,3 +121,13 @@ def recommended_column_not_null_assertion(table, column, profiling_result) -> Re
         return assertion
     else:
         return None
+
+
+RecommendedRules = [
+    recommended_table_row_count_assertion,
+    recommended_column_schema_type_assertion,
+    recommended_column_min_assertion,
+    recommended_column_max_assertion,
+    recommended_column_unique_assertion,
+    recommended_column_not_null_assertion,
+]
