@@ -3,6 +3,7 @@ import os
 import sys
 from datetime import datetime
 
+import inquirer
 import readchar
 from rich.console import Console
 
@@ -89,9 +90,10 @@ class ComparisonData(object):
         return json.dumps(output, separators=(',', ':'))
 
 
-def prepare_default_output_path(comparison_dir: str, created_at):
-    latest_symlink_path = os.path.join(comparison_dir, 'latest')
-    comparison_path = os.path.join(comparison_dir, created_at)
+def prepare_default_output_path(filesystem: FileSystem, created_at):
+    latest_symlink_path = os.path.join(filesystem.get_comparison_dir(), 'latest')
+    latest_source = created_at
+    comparison_path = os.path.join(filesystem.get_comparison_dir(), created_at)
 
     if not os.path.exists(comparison_path):
         os.makedirs(comparison_path, exist_ok=True)
@@ -100,7 +102,7 @@ def prepare_default_output_path(comparison_dir: str, created_at):
     if os.path.islink(latest_symlink_path):
         os.unlink(latest_symlink_path)
     if not os.path.exists(latest_symlink_path):
-        os.symlink(comparison_path, latest_symlink_path)
+        os.symlink(latest_source, latest_symlink_path)
     else:
         console = Console()
         console.print(f'[bold yellow]Warning: {latest_symlink_path} already exists[/bold yellow]')
@@ -168,9 +170,12 @@ class CompareReport(object):
             return True
         return False
 
-    def select_one_report(self) -> ProfilerOutput:
+    def select_multiple_reports(self, action='compare', limit=None):
         def _report_validater(answers, current) -> bool:
-            return len(current) == 1
+            if limit is None:
+                return len(current) > 0
+            else:
+                return len(current) == limit
 
         profiler_outputs = self.list_existing_outputs()
         arrow_alias_msg = ''
@@ -180,59 +185,51 @@ class CompareReport(object):
             readchar.key.DOWN = 's'
             arrow_alias_msg = " 'w' to Up, 's' to Down,"
 
-        if len(profiler_outputs) < 1:
-            raise Exception("Not enough reports to compare. Please run 'piperider run' first.")
+        if limit is None:
+            if len(profiler_outputs) == 0:
+                raise Exception("Not enough reports to compare. Please run 'piperider run' first.")
+            questions = [
+                inquirer.Checkbox('profiler_output',
+                                  message=f"Please select the reports to {action} ({arrow_alias_msg} SPACE to select, and ENTER to confirm )",
+                                  choices=profiler_outputs,
+                                  carousel=True,
+                                  validate=_report_validater,
+                                  )
+            ]
+        else:
+            if len(profiler_outputs) < limit:
+                raise Exception("Not enough reports to compare. Please run 'piperider run' first.")
+            report_msg = 'a report' if limit == 1 else f'the {limit} reports'
+            questions = [
+                inquirer_hack.LimitedCheckboxQuestion('profiler_output',
+                                                      message=f"Please select {report_msg} to {action} ({arrow_alias_msg} SPACE to select, and ENTER to confirm )",
+                                                      choices=profiler_outputs,
+                                                      carousel=True,
+                                                      validate=_report_validater,
+                                                      limited=limit,
+                                                      )
+            ]
 
-        questions = [
-            inquirer_hack.LimitedCheckboxQuestion('profiler_output',
-                                                  message=f"Please select a report to compare ({arrow_alias_msg} SPACE to select, and ENTER to confirm )",
-                                                  choices=profiler_outputs,
-                                                  carousel=True,
-                                                  validate=_report_validater,
-                                                  limited=1,
-                                                  )
-        ]
         answers = inquirer_hack.prompt_ex(questions, raise_keyboard_interrupt=True)
-
         if answers:
-            return answers['profiler_output'][0]
+            return answers['profiler_output']
+        return None
+
+    def select_one_report(self, action='compare') -> ProfilerOutput:
+        answers = self.select_multiple_reports(action=action, limit=1)
+        if answers:
+            return answers[0]
         else:
             return None
 
-    def select_two_reports(self) -> (ProfilerOutput, ProfilerOutput):
+    def select_two_reports(self, action='compare') -> (ProfilerOutput, ProfilerOutput):
         """
         Select multiple files from a list of files.
         """
 
-        # execution.
-
-        def _report_validater(answers, current) -> bool:
-            return len(current) == 2
-
-        profiler_outputs = self.list_existing_outputs()
-        arrow_alias_msg = ''
-        if sys.platform == "win32" or sys.platform == "cygwin":
-            # change readchar key UP & DOWN by 'w' and 's'
-            readchar.key.UP = 'w'
-            readchar.key.DOWN = 's'
-            arrow_alias_msg = " 'w' to Up, 's' to Down,"
-
-        if len(profiler_outputs) < 2:
-            raise Exception("Not enough reports to compare. Please run 'piperider run' first.")
-
-        questions = [
-            inquirer_hack.LimitedCheckboxQuestion(
-                'profiler_outputs',
-                message=f"Please select the 2 reports to compare ({arrow_alias_msg} SPACE to select, and ENTER to confirm )",
-                choices=profiler_outputs,
-                carousel=True,
-                validate=_report_validater,
-                limited=2,
-            ),
-        ]
-        answers = inquirer_hack.prompt_ex(questions, raise_keyboard_interrupt=True)
+        answers = self.select_multiple_reports(action=action, limit=2)
         if answers:
-            return answers['profiler_outputs'][0], answers['profiler_outputs'][1]
+            return answers[0], answers[1]
         return None, None
 
     def generate_data(self) -> ComparisonData:
@@ -266,7 +263,7 @@ class CompareReport(object):
                 f.write(html)
 
         data_id = comparison_data.id()
-        default_report_directory = prepare_default_output_path(filesystem.get_comparison_dir(), data_id)
+        default_report_directory = prepare_default_output_path(filesystem, data_id)
         output_report(default_report_directory)
         report_path = os.path.join(filesystem.get_comparison_dir(), 'latest', 'index.html')
 
