@@ -17,6 +17,7 @@ from sqlalchemy.sql.expression import CTE, false, true, table as table_clause, c
 from sqlalchemy.types import Float
 
 from .event import ProfilerEventHandler, DefaultProfilerEventHandler
+from ..configuration import Configuration
 
 HISTOGRAM_NUM_BUCKET = 50
 
@@ -72,10 +73,12 @@ class Profiler:
     inspector: Inspector = None
     event_handler: ProfilerEventHandler
 
-    def __init__(self, engine: Engine, event_handler: ProfilerEventHandler = DefaultProfilerEventHandler()):
+    def __init__(self, engine: Engine, event_handler: ProfilerEventHandler = DefaultProfilerEventHandler(),
+                 config: Configuration = None):
         self.engine = engine
         self.inspector = inspect(self.engine) if self.engine else None
         self.event_handler = event_handler
+        self.config = config
 
     def profile(self, tables: List[str] = None) -> dict:
         """
@@ -89,7 +92,7 @@ class Profiler:
         - boolean
         - Other
 
-        :param tables: optinoal, the tables to profile
+        :param tables: optional, the tables to profile
         :return: the profile results
         """
 
@@ -105,8 +108,10 @@ class Profiler:
             if not tables:
                 self.event_handler.handle_fetch_metadata_all_start()
                 metadata.reflect(bind=self.engine)
-                tables = self.metadata.tables.keys()
+                tables = list(self.metadata.tables.keys())
+                tables = self._apply_incl_excl_tables(tables)
             else:
+                tables = self._apply_incl_excl_tables(tables)
                 for table in tables:
                     self.event_handler.handle_fetch_metadata_table_start(table)
                     if len(table.split('.')) == 2:
@@ -117,6 +122,7 @@ class Profiler:
         table_count = len(tables)
         table_index = 0
         self.event_handler.handle_run_progress(result, table_count, table_index)
+
         for table_name in tables:
             t = self.metadata.tables[table_name]
             tresult = self._profile_table(t)
@@ -128,6 +134,26 @@ class Profiler:
 
         return result
 
+    def _apply_incl_excl_tables(self, tables: List[str]) -> List[str]:
+        if not self.config:
+            return tables
+        if self.config.includes is None and self.config.excludes is None:
+            return tables
+
+        if self.config.includes is None:
+            allow_list = tables
+        else:
+            upper_includes = [t.upper() for t in self.config.includes]
+            allow_list = [t for t in tables if t.upper() in upper_includes]
+
+        if self.config.excludes is None:
+            final_list = allow_list
+        else:
+            upper_excludes = [t.upper() for t in self.config.excludes]
+            final_list = [t for t in allow_list if t.upper() not in upper_excludes]
+
+        return final_list
+
     def _drop_unsupported_columns(self, table: Table):
         array_columns = []
         candidate_columns = []
@@ -200,7 +226,13 @@ class Profiler:
                     ]).select_from(table)
                     row_count, = conn.execute(stmt).fetchone()
 
-        result['row_count'] = row_count
+        result['row_count'] = result['samples'] = row_count
+
+        if self.config:
+            limit = self.config.profiler_config.get('table', {}).get('limit', 0)
+            if row_count > limit > 0:
+                result['samples'] = limit
+
         if created:
             result['created'] = created
         if last_altered:
@@ -210,6 +242,47 @@ class Profiler:
         if size_bytes:
             result['bytes'] = size_bytes
 
+    def _profile_table_duplicate_rows(self, result: dict, table: Table):
+        if not self.config:
+            return
+        if not self.config.profiler_config.get('table', {}).get('duplicateRows'):
+            return
+
+        limit = self.config.profiler_config.get('table', {}).get('limit', 0)
+        columns = [column.label(f'_{column.name}') for column in table.columns]
+
+        with self.engine.connect() as conn:
+            if self.engine.url.get_backend_name() == 'snowflake':
+                if limit <= 0:
+                    cte = select([func.hash(*columns).label('h')]).select_from(table).cte()
+                else:
+                    cte = select([func.hash(*columns).label('h')]).select_from(table).limit(limit).cte()
+
+                cte = select([
+                    cte.c.h,
+                    func.count().label('c')
+                ]).select_from(cte).group_by(cte.c.h).having(func.count() > 1).cte()
+                stmt = select([func.sum(cte.c.c)]).select_from(cte)
+                duplicate_rows, = conn.execute(stmt).fetchone()
+            else:
+                if limit <= 0:
+                    cte = select([
+                        *columns,
+                        func.count().label('c')
+                    ]).select_from(table).group_by(*columns).having(func.count() > 1).cte()
+                else:
+                    cte = select([*columns]).select_from(table).limit(limit).cte()
+                    columns = [column for column in cte.columns]
+                    cte = select([
+                        *columns,
+                        func.count().label('c')
+                    ]).select_from(cte).group_by(*columns).having(func.count() > 1).cte()
+
+                stmt = select([func.sum(cte.c.c)]).select_from(cte)
+                duplicate_rows, = conn.execute(stmt).fetchone()
+
+            result['duplicate_rows'] = duplicate_rows if duplicate_rows is not None else 0
+
     def _profile_table(self, table: Table) -> dict:
         candidate_columns = self._drop_unsupported_columns(table)
         col_index = 0
@@ -218,6 +291,7 @@ class Profiler:
         result = {
             "name": table.name,
             "row_count": 0,
+            "samples": 0,
             "col_count": col_count,
             "columns": columns
         }
@@ -230,12 +304,14 @@ class Profiler:
 
         # Profile table metrics
         self._profile_table_metadata(result, table)
+        self._profile_table_duplicate_rows(result, table)
         self.event_handler.handle_table_progress(result, col_count, col_index)
 
         # Profile columns
         if isinstance(self.engine.pool, SingletonThreadPool):
             for column in candidate_columns:
                 columns[column.name] = self._profile_column(table, column)
+                columns[column.name]['total'] = result['row_count']
                 col_index = col_index + 1
                 self.event_handler.handle_table_progress(result, col_count, col_index)
 
@@ -253,6 +329,7 @@ class Profiler:
                             raise exc
                         else:
                             columns[column.name] = data
+                            columns[column.name]['total'] = result['row_count']
                             col_index = col_index + 1
                             self.event_handler.handle_table_progress(result, col_count, col_index)
                 finally:
@@ -261,39 +338,40 @@ class Profiler:
         return result
 
     def _profile_column(self, table: Table, column: Column) -> dict:
+        profiler_config = self.config.profiler_config if self.config else {}
         if isinstance(column.type, String):
             # VARCHAR
             # CHAR
             # TEXT
             # CLOB
             generic_type = "string"
-            profiler = StringColumnProfiler(self.engine, table, column)
+            profiler = StringColumnProfiler(self.engine, profiler_config, table, column)
         elif isinstance(column.type, Integer):
             # INTEGER
             # BIGINT
             # SMALLINT
             generic_type = "integer"
-            profiler = NumericColumnProfiler(self.engine, table, column, is_integer=True)
+            profiler = NumericColumnProfiler(self.engine, profiler_config, table, column, is_integer=True)
         elif isinstance(column.type, Numeric):
             # NUMERIC
             # DECIMAL
             # FLOAT
             generic_type = "numeric"
-            profiler = NumericColumnProfiler(self.engine, table, column, is_integer=False)
+            profiler = NumericColumnProfiler(self.engine, profiler_config, table, column, is_integer=False)
         elif isinstance(column.type, Date) or isinstance(column.type, DateTime) or \
             (self.engine.url.get_backend_name() == 'snowflake' and str(column.type).startswith('TIMESTAMP')):
             # DATE
             # DATETIME
             # TIMEZONE_NTZ
             generic_type = "datetime"
-            profiler = DatetimeColumnProfiler(self.engine, table, column)
+            profiler = DatetimeColumnProfiler(self.engine, profiler_config, table, column)
         elif isinstance(column.type, Boolean):
             # BOOLEAN
             generic_type = "boolean"
-            profiler = BooleanColumnProfiler(self.engine, table, column)
+            profiler = BooleanColumnProfiler(self.engine, profiler_config, table, column)
         else:
             generic_type = "other"
-            profiler = BaseColumnProfiler(self.engine, table, column)
+            profiler = BaseColumnProfiler(self.engine, profiler_config, table, column)
 
         result = {
             "name": column.name,
@@ -323,11 +401,13 @@ class BaseColumnProfiler:
     """
 
     engine: Engine = None
+    config: dict = None
     table: Table = None
     column: Column = None
 
-    def __init__(self, engine: Engine, table: Table, column: Column):
+    def __init__(self, engine: Engine, config: dict, table: Table, column: Column):
         self.engine = engine
+        self.config = config
         self.table = table
         self.column = column
 
@@ -338,6 +418,19 @@ class BaseColumnProfiler:
         """
         return self.engine.url.get_backend_name()
 
+    def _get_limited_table_cte(self):
+        t = self.table
+        c = self.column
+        if not self.config:
+            return t, c
+
+        limit = self.config.get('table', {}).get('limit', 0)
+        if limit <= 0:
+            return t, c
+        else:
+            cte = select([c.label('c')]).select_from(t).limit(limit).cte()
+            return cte, cte.c.c
+
     def _get_table_cte(self) -> CTE:
         """
         Get the CTE to normalize the
@@ -359,8 +452,7 @@ class BaseColumnProfiler:
 
         :return: CTE
         """
-        t = self.table
-        c = self.column
+        t, c = self._get_limited_table_cte()
 
         return select([c.label("c")]).select_from(t).cte()
 
@@ -381,7 +473,8 @@ class BaseColumnProfiler:
             _total, _non_nulls, = result
 
             return {
-                'total': _total,
+                'total': None,
+                'samples': _total,
                 'non_nulls': _non_nulls,
                 'nulls': _total - _non_nulls,
                 'valids': _non_nulls,
@@ -391,12 +484,11 @@ class BaseColumnProfiler:
 
 
 class StringColumnProfiler(BaseColumnProfiler):
-    def __init__(self, engine: Engine, table: Table, column: Column):
-        super().__init__(engine, table, column)
+    def __init__(self, engine: Engine, config: dict, table: Table, column: Column):
+        super().__init__(engine, config, table, column)
 
     def _get_table_cte(self) -> CTE:
-        t = self.table
-        c = self.column
+        t, c = self._get_limited_table_cte()
         if self._get_database_backend() != 'sqlite':
             cte = select([
                 c.label("c"),
@@ -426,31 +518,44 @@ class StringColumnProfiler(BaseColumnProfiler):
     def profile(self):
         with self.engine.connect() as conn:
             cte = self._get_table_cte()
-            stmt = select([
+
+            columns = [
                 func.count().label("_total"),
                 func.count(cte.c.orig).label("_non_nulls"),
                 func.count(cte.c.c).label("_valids"),
                 func.count(cte.c.zero_length).label("_zero_length"),
                 func.count(distinct(cte.c.c)).label("_distinct"),
-                func.sum(cte.c.len).label("_sum"),
+                func.sum(func.cast(cte.c.len, Float)).label("_sum"),
                 func.avg(cte.c.len).label("_avg"),
                 func.min(cte.c.len).label("_min"),
                 func.max(cte.c.len).label("_max"),
-                func.avg(func.cast(cte.c.len, Float) * func.cast(cte.c.len, Float)).label("_square_avg"),
-            ])
-            result = conn.execute(stmt).fetchone()
-            _total, _non_nulls, _valids, _zero_length, _distinct, _sum, _avg, _min, _max, _square_avg = result
+            ]
+
+            if self._get_database_backend() == 'sqlite':
+                columns.append((func.count(cte.c.len) * func.sum(
+                    func.cast(cte.c.len, Float) * func.cast(cte.c.len, Float)) - func.sum(cte.c.len) * func.sum(
+                    cte.c.len)) / ((func.count(cte.c.len) - 1) * func.count(cte.c.len)).label('_variance'))
+                stmt = select(columns)
+                result = conn.execute(stmt).fetchone()
+                _total, _non_nulls, _valids, _zero_length, _distinct, _sum, _avg, _min, _max, _variance = result
+                _stddev = None
+                if _variance is not None:
+                    _stddev = math.sqrt(_variance)
+            else:
+                columns.append(func.stddev(cte.c.len).label("_stddev"))
+                stmt = select(columns)
+                result = conn.execute(stmt).fetchone()
+                _total, _non_nulls, _valids, _zero_length, _distinct, _sum, _avg, _min, _max, _stddev = result
+
             _sum = dtof(_sum)
             _min = dtof(_min)
             _max = dtof(_max)
             _avg = dtof(_avg)
-            _square_avg = dtof(_square_avg)
-            _stddev = None
-            if _square_avg is not None and _avg is not None:
-                _stddev = math.sqrt(_square_avg - _avg * _avg)
+            _stddev = dtof(_stddev)
 
             result = {
-                'total': _total,
+                'total': None,
+                'samples': _total,
                 'non_nulls': _non_nulls,
                 'nulls': _total - _non_nulls,
                 'valids': _valids,
@@ -498,13 +603,12 @@ class StringColumnProfiler(BaseColumnProfiler):
 class NumericColumnProfiler(BaseColumnProfiler):
     is_integer: bool
 
-    def __init__(self, engine: Engine, table: Table, column: Column, is_integer: bool):
-        super().__init__(engine, table, column)
+    def __init__(self, engine: Engine, config: dict, table: Table, column: Column, is_integer: bool):
+        super().__init__(engine, config, table, column)
         self.is_integer = is_integer
 
     def _get_table_cte(self) -> CTE:
-        t = self.table
-        c = self.column
+        t, c = self._get_limited_table_cte()
         if self._get_database_backend() != 'sqlite':
             cte = select([
                 c.label("c"),
@@ -531,32 +635,44 @@ class NumericColumnProfiler(BaseColumnProfiler):
         with self.engine.connect() as conn:
             cte = self._get_table_cte()
 
-            stmt = select([
+            columns = [
                 func.count().label("_total"),
                 func.count(cte.c.orig).label("_non_nulls"),
                 func.count(cte.c.c).label("_valids"),
                 func.count(cte.c.zero).label("_zeros"),
                 func.count(cte.c.negative).label("_negatives"),
                 func.count(distinct(cte.c.c)).label("_distinct"),
-                func.sum(cte.c.c).label("_sum"),
+                func.sum(func.cast(cte.c.c, Float)).label("_sum"),
                 func.avg(cte.c.c).label("_avg"),
                 func.min(cte.c.c).label("_min"),
                 func.max(cte.c.c).label("_max"),
-                func.avg(func.cast(cte.c.c, Float) * func.cast(cte.c.c, Float)).label("_square_avg"),
-            ])
-            result = conn.execute(stmt).fetchone()
-            _total, _non_nulls, _valids, _zeros, _negatives, _distinct, _sum, _avg, _min, _max, _square_avg = result
+            ]
+
+            if self._get_database_backend() == 'sqlite':
+                columns.append((func.count(cte.c.c) * func.sum(
+                    func.cast(cte.c.c, Float) * func.cast(cte.c.c, Float)) - func.sum(cte.c.c) * func.sum(cte.c.c)) / (
+                    (func.count(cte.c.c) - 1) * func.count(cte.c.c)).label('_variance'))
+                stmt = select(columns)
+                result = conn.execute(stmt).fetchone()
+                _total, _non_nulls, _valids, _zeros, _negatives, _distinct, _sum, _avg, _min, _max, _variance = result
+                _stddev = None
+                if _variance is not None:
+                    _stddev = math.sqrt(_variance)
+            else:
+                columns.append(func.stddev(cte.c.c).label("_stddev"))
+                stmt = select(columns)
+                result = conn.execute(stmt).fetchone()
+                _total, _non_nulls, _valids, _zeros, _negatives, _distinct, _sum, _avg, _min, _max, _stddev = result
+
             _sum = dtof(_sum)
             _min = dtof(_min)
             _max = dtof(_max)
             _avg = dtof(_avg)
-            _square_avg = dtof(_square_avg)
-            _stddev = None
-            if _square_avg is not None and _avg is not None:
-                _stddev = math.sqrt(_square_avg - _avg * _avg)
+            _stddev = dtof(_stddev)
 
             result = {
-                'total': _total,
+                'total': None,
+                'samples': _total,
                 'non_nulls': _non_nulls,
                 'nulls': _total - _non_nulls,
                 'valids': _valids,
@@ -840,12 +956,11 @@ class NumericColumnProfiler(BaseColumnProfiler):
 
 
 class DatetimeColumnProfiler(BaseColumnProfiler):
-    def __init__(self, engine, table: Table, column: Column):
-        super().__init__(engine, table, column)
+    def __init__(self, engine: Engine, config: dict, table: Table, column: Column):
+        super().__init__(engine, config, table, column)
 
     def _get_table_cte(self) -> CTE:
-        t = self.table
-        c = self.column
+        t, c = self._get_limited_table_cte()
         if self._get_database_backend() != 'sqlite':
             cte = select([
                 c.label("c"),
@@ -886,7 +1001,8 @@ class DatetimeColumnProfiler(BaseColumnProfiler):
                     _max = datetime.fromisoformat(_max) if isinstance(_max, str) else _max
 
             result = {
-                'total': _total,
+                'total': None,
+                'samples': _total,
                 'non_nulls': _non_nulls,
                 'nulls': _total - _non_nulls,
                 'valids': _valids,
@@ -1033,12 +1149,11 @@ class DatetimeColumnProfiler(BaseColumnProfiler):
 
 
 class BooleanColumnProfiler(BaseColumnProfiler):
-    def __init__(self, engine: Engine, table: Table, column: Column):
-        super().__init__(engine, table, column)
+    def __init__(self, engine: Engine, config: dict, table: Table, column: Column):
+        super().__init__(engine, config, table, column)
 
     def _get_table_cte(self) -> CTE:
-        t = self.table
-        c = self.column
+        t, c = self._get_limited_table_cte()
         if self._get_database_backend() != 'sqlite':
             cte = select([
                 c.label("c"),
@@ -1076,7 +1191,8 @@ class BooleanColumnProfiler(BaseColumnProfiler):
             _falses = _valids - _trues
 
             return {
-                'total': _total,
+                'total': None,
+                'samples': _total,
                 'non_nulls': _non_nulls,
                 'nulls': _total - _non_nulls,
                 'valids': _valids,
