@@ -6,9 +6,11 @@ import uuid
 from datetime import datetime
 
 from rich import box
+from rich.color import Color
 from rich.console import Console
 from rich.pretty import Pretty
 from rich.progress import Progress, Column, TextColumn, BarColumn, TimeElapsedColumn, MofNCompleteColumn
+from rich.style import Style
 from rich.table import Table
 
 from piperider_cli import convert_to_tzlocal, datetime_to_str, clone_directory, \
@@ -20,6 +22,7 @@ from piperider_cli.assertion_engine.recommender import RECOMMENDED_ASSERTION_TAG
 from piperider_cli.configuration import Configuration
 from piperider_cli.datasource import DataSource
 from piperider_cli.error import PipeRiderCredentialError
+from piperider_cli.exitcode import EC_ERR_TEST_FAILED
 from piperider_cli.filesystem import FileSystem
 from piperider_cli.profiler import Profiler, ProfilerEventHandler
 
@@ -50,7 +53,7 @@ class RichProfilerEventHandler(ProfilerEventHandler):
         table_width, total_width = self._get_width(tables)
         total_column = TextColumn("{task.fields[coft]}", table_column=Column(width=total_width))
         text_column = TextColumn("{task.description}", table_column=Column(width=table_width))
-        bar_column = BarColumn(bar_width=80)
+        bar_column = BarColumn(bar_width=80, pulse_style=Style.from_color(Color.from_rgb(244, 164, 96)))
         mofn_column = MofNCompleteColumn(table_column=Column(width=5, justify="right"))
         time_elapsed_column = TimeElapsedColumn()
 
@@ -64,12 +67,10 @@ class RichProfilerEventHandler(ProfilerEventHandler):
         return max([len(x) for x in tables]), len(str(len(tables))) * 2 + 2
 
     def handle_run_start(self, run_result):
-        pass
+        self.progress.start()
 
     def handle_run_progress(self, run_result, total, completed):
         self.table_total = total
-        self.table_completed = completed
-        pass
 
     def handle_run_end(self, run_result):
         self.progress.stop()
@@ -81,22 +82,21 @@ class RichProfilerEventHandler(ProfilerEventHandler):
         print(f"fetching metadata for table '{table_name}'")
 
     def handle_table_start(self, table_result):
-        pass
+        self.table_completed += 1
+        table_name = table_result['name']
+        padding = ' ' * (len(str(self.table_total)) - len(str(self.table_completed)))
+        coft = f'[{padding}{self.table_completed}/{self.table_total}]'
+        task_id = self.progress.add_task(table_name, total=None, **dict(coft=coft))
+        self.tasks[table_name] = task_id
 
     def handle_table_progress(self, table_result, total, completed):
         if completed == 0:
             table_name = table_result['name']
-            padding = ' ' * (len(str(self.table_total)) - len(str(self.table_completed + 1)))
-            coft = f'[{padding}{self.table_completed + 1}/{self.table_total}]'
-            task_id = self.progress.add_task(table_name, total=total, **dict(coft=coft))
-            self.tasks[table_name] = task_id
-            self.progress.start()
+            task_id = self.tasks[table_name]
+            self.progress.update(task_id, total=total)
 
     def handle_table_end(self, table_result):
-        self.progress.stop()
-        table_name = table_result['name']
-        task_id = self.tasks[table_name]
-        self.progress.remove_task(task_id)
+        pass
 
     def handle_column_start(self, table_name, column_result):
         pass
@@ -395,10 +395,10 @@ def _get_table_list(table, default_schema, dbt_adapter):
     return tables
 
 
-def prepare_default_output_path(filesytem: FileSystem, created_at, ds):
-    latest_symlink_path = os.path.join(filesytem.get_output_dir(), 'latest')
-    output_path = os.path.join(filesytem.get_output_dir(),
-                               f"{ds.name}-{convert_to_tzlocal(created_at).strftime('%Y%m%d%H%M%S')}")
+def prepare_default_output_path(filesystem: FileSystem, created_at, ds):
+    latest_symlink_path = os.path.join(filesystem.get_output_dir(), 'latest')
+    latest_source = f"{ds.name}-{convert_to_tzlocal(created_at).strftime('%Y%m%d%H%M%S')}"
+    output_path = os.path.join(filesystem.get_output_dir(), latest_source)
 
     if not os.path.exists(output_path):
         os.makedirs(output_path, exist_ok=True)
@@ -407,7 +407,7 @@ def prepare_default_output_path(filesytem: FileSystem, created_at, ds):
     if os.path.islink(latest_symlink_path):
         os.unlink(latest_symlink_path)
     if not os.path.exists(latest_symlink_path):
-        os.symlink(output_path, latest_symlink_path)
+        os.symlink(latest_source, latest_symlink_path)
     else:
         console = Console()
         console.print(f'[bold yellow]Warning: {latest_symlink_path} already exists[/bold yellow]')
@@ -447,7 +447,7 @@ def _append_descriptions_from_assertion(profile_result):
         for column_name, column_v in columns_content.items():
             if column_name not in profile_result['tables'][table_name]['columns'] or column_v is None:
                 continue
-            column_desc = column_v.get('description', column_name)
+            column_desc = column_v.get('description', '')
             if column_desc:
                 profile_result['tables'][table_name]['columns'][column_name][
                     'description'] = f'{column_desc} - via PipeRider'
@@ -505,6 +505,25 @@ def decorate_with_metadata(profile_result: dict):
     profile_result['metadata_version'] = schema_version()
 
 
+def _check_test_status(assertion_results, assertion_exceptions, dbt_test_results):
+    if assertion_exceptions and len(assertion_exceptions) > 0:
+        return False
+
+    if assertion_results:
+        for assertion in assertion_results:
+            if not assertion.result.status():
+                return False
+
+    if dbt_test_results:
+        for table, v in dbt_test_results.items():
+            for column, results in v['columns'].items():
+                for r in results:
+                    if r.get('status') == 'failed':
+                        return False
+
+    return True
+
+
 class Runner():
     @staticmethod
     def exec(datasource=None, table=None, output=None, interaction=True, skip_report=False, dbt_command='',
@@ -514,7 +533,7 @@ class Runner():
         raise_exception_when_directory_not_writable(output)
 
         configuration = Configuration.load()
-        filesytem = FileSystem(report_dir=report_dir)
+        filesystem = FileSystem(report_dir=report_dir)
         datasources = {}
         datasource_names = []
         for ds in configuration.dataSources:
@@ -579,7 +598,13 @@ class Runner():
         run_id = uuid.uuid4().hex
         created_at = datetime.utcnow()
         engine = ds.create_engine()
-        profiler = Profiler(engine, RichProfilerEventHandler(tables if tables else available_tables))
+
+        if table:
+            # cli --table is specified, no inclusion and exclusion applied
+            configuration.includes = None
+            configuration.excludes = None
+
+        profiler = Profiler(engine, RichProfilerEventHandler(tables if tables else available_tables), configuration)
         try:
             profile_result = profiler.profile(tables)
             decorate_with_metadata(profile_result)
@@ -612,7 +637,7 @@ class Runner():
                     continue
                 profile_result['tables'][k]['dbt_assertion_result'] = v
 
-        output_path = prepare_default_output_path(filesytem, created_at, ds)
+        output_path = prepare_default_output_path(filesystem, created_at, ds)
         output_file = os.path.join(output_path, 'run.json')
         for t in profile_result['tables']:
             profile_result['tables'][t]['piperider_assertion_result'] = _transform_assertion_result(t,
@@ -621,7 +646,6 @@ class Runner():
         _show_summary(profile_result, assertion_results, assertion_exceptions, dbt_test_results)
         _show_recommended_assertion_notice_message(console, assertion_results)
 
-        _append_descriptions(profile_result)
         if dbt_adapter.is_ready():
             dbt_adapter.append_descriptions(profile_result, default_schema)
         _append_descriptions_from_assertion(profile_result)
@@ -637,4 +661,7 @@ class Runner():
 
         _analyse_and_log_run_event(profile_result, assertion_results, dbt_test_results, dbt_command)
 
+        if not _check_test_status(assertion_results, assertion_exceptions, dbt_test_results):
+            return EC_ERR_TEST_FAILED
+
         return 0
